.. image:: https://travis-ci.org/jbn/dissertate.svg?branch=master
    :target: https://travis-ci.org/jbn/dissertate
.. image:: https://ci.appveyor.com/api/projects/status/69kj3prrrieyp8q2/branch/master?svg=true
    :target: https://ci.appveyor.com/project/jbn/dissertate/branch/master 
.. image:: https://coveralls.io/repos/github/jbn/dissertate/badge.svg?branch=master
    :target: https://coveralls.io/github/jbn/dissertate?branch=master 
.. image:: https://img.shields.io/pypi/v/dissertate.svg
    :target: https://pypi.python.org/pypi/dissertate
.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target: https://raw.githubusercontent.com/jbn/dissertate/master/LICENSE
.. image:: https://img.shields.io/pypi/pyversions/dissertate.svg
    :target: https://pypi.python.org/pypi/dissertate

